@@ -70,9 +70,15 @@ void ContextMenu::restore(const KConfigGroup &config)
                       << QStringLiteral("add widgets")
                       << QStringLiteral("_add panel")
                       << QStringLiteral("manage activities")
-                      << QStringLiteral("remove")
-                      << QStringLiteral("edit mode")
-                      << QStringLiteral("_sep2")
+                      << QStringLiteral("remove");
+
+        if (c->containmentType() == Plasma::Containment::Desktop) {
+            m_actionOrder << QStringLiteral("desktop edit mode");
+        } else {
+            m_actionOrder << QStringLiteral("edit mode");
+        }
+
+        m_actionOrder << QStringLiteral("_sep2")
                       << QStringLiteral("_lock_screen")
                       << QStringLiteral("_logout")
                       << QStringLiteral("_sep3")
@@ -105,7 +111,7 @@ void ContextMenu::restore(const KConfigGroup &config)
         connect(m_runCommandAction, &QAction::triggered, this, &ContextMenu::runCommand);
 
         m_openTerminalAction = new QAction(i18n("Open Terminal"), this);
-        m_openTerminalAction->setIcon(QIcon::fromTheme("utilities-terminal"));
+        m_openTerminalAction->setIcon(QIcon::fromTheme(u"utilities-terminal"_s));
         connect(m_openTerminalAction, &QAction::triggered, this, &ContextMenu::openTerminal);
 
         m_lockScreenAction = new QAction(i18nc("plasma_containmentactions_contextmenu", "Lock Screen"), this);
@@ -117,7 +123,7 @@ void ContextMenu::restore(const KConfigGroup &config)
         });
         connect(m_lockScreenAction, &QAction::triggered, m_session, &SessionManagement::lock);
 
-        m_logoutAction = new QAction(i18nc("plasma_containmentactions_contextmenu", "Leave…"), this);
+        m_logoutAction = new QAction(i18nc("plasma_containmentactions_contextmenu", "Show Logout Screen"), this);
         m_logoutAction->setIcon(QIcon::fromTheme(QStringLiteral("system-log-out")));
         m_logoutAction->setShortcut(KGlobalAccel::self()->globalShortcut(QStringLiteral("ksmserver"), QStringLiteral("Show Logout Prompt")).value(0));
         connect(m_logoutAction, &QAction::triggered, this, &ContextMenu::startLogout);
