@@ -28,7 +28,7 @@ void SwitchActivity::makeMenu()
 {
     qDeleteAll(m_actions);
     m_actions.clear();
-    foreach (const QString &id, m_consumer.activities(KActivities::Info::Running)) {
+    for (const auto activities = m_consumer.activities(KActivities::Info::Running); const QString &id : activities) {
         KActivities::Info info(id);
         QAction *action = new QAction(QIcon::fromTheme(info.icon()), info.name(), this);
         action->setData(id);
