@@ -253,26 +253,26 @@ bool WetterComIon::updateIonSource(const QString &source)
 
     if (sourceAction[1] == QLatin1String("weather") && sourceAction.size() >= 3) {
         if (sourceAction.count() >= 4) {
-            if (sourceAction[2].isEmpty()) {
+            if (sourceAction[3].isEmpty()) {
                 setData(source, QStringLiteral("validate"), QStringLiteral("wettercom|malformed"));
                 return true;
             }
 
             // Extra data format: placeCode;displayName
             const QStringList extraData = sourceAction[3].split(QLatin1Char(';'));
-
             if (extraData.count() != 2) {
                 setData(source, QStringLiteral("validate"), QStringLiteral("wettercom|malformed"));
                 return true;
             }
 
-            m_place[sourceAction[2]].placeCode = extraData[0];
+            const QString &placeCode = extraData[0];
+            m_place[placeCode].name = sourceAction[2];
+            m_place[placeCode].placeCode = placeCode;
+            m_place[placeCode].displayName = extraData[1];
 
-            m_place[sourceAction[2]].displayName = extraData[1];
+            qCDebug(IONENGINE_WETTERCOM) << "About to retrieve forecast for source: " << placeCode << sourceAction[2];
 
-            qCDebug(IONENGINE_WETTERCOM) << "About to retrieve forecast for source: " << sourceAction[2];
-
-            fetchForecast(sourceAction[2]);
+            fetchForecast(placeCode);
 
             return true;
         }
@@ -297,6 +297,7 @@ void WetterComIon::findPlace(const QString &place, const QString &source)
     const QString encodedKey = QString::fromLatin1(md5.result().toHex());
 
     const QUrl url(QStringLiteral(SEARCH_URL).arg(place, encodedKey));
+    qCDebug(IONENGINE_WETTERCOM) << "Search URL for" << place << url;
 
     KIO::TransferJob *getJob = KIO::get(url, KIO::Reload, KIO::HideProgressInfo);
     getJob->addMetaData(QStringLiteral("cookies"), QStringLiteral("none")); // Disable displaying cookies
@@ -363,13 +364,13 @@ void WetterComIon::parseSearchResults(const QString &source, QXmlStreamReader &x
                     placeName = i18nc("Geographical location: quarter (city), state, ISO-country-code", "%1 (%2), %3, %4", quarter, name, state, country);
                 }
 
-                qCDebug(IONENGINE_WETTERCOM) << "Storing place data for place:" << placeName;
+                qCDebug(IONENGINE_WETTERCOM) << "Storing place data for place:" << placeName << "with code" << code;
 
-                PlaceInfo &place = m_place[placeName];
+                PlaceInfo &place = m_place[code];
                 place.name = placeName;
                 place.displayName = name;
                 place.placeCode = code;
-                m_locations.append(placeName);
+                m_locations.append(code);
 
                 name.clear();
                 code.clear();
@@ -403,7 +404,7 @@ void WetterComIon::validate(const QString &source, bool parseError)
         const QString invalidPlace = source.section(QLatin1Char('|'), 2, 2);
 
         if (m_place[invalidPlace].name.isEmpty()) {
-            setData(source, QStringLiteral("validate"), QVariant(QLatin1String("wettercom|invalid|multiple|") + invalidPlace));
+            setData(source, QStringLiteral("validate"), QVariant(QString(u"wettercom|invalid|multiple|" + invalidPlace)));
         }
 
         m_locations.clear();
@@ -412,19 +413,19 @@ void WetterComIon::validate(const QString &source, bool parseError)
     }
 
     QString placeList;
-    for (const QString &place : std::as_const(m_locations)) {
+    for (const QString &code : std::as_const(m_locations)) {
+        const PlaceInfo &place = m_place[code];
         // Extra data format: placeCode;displayName
-        placeList.append(QLatin1String("|place|") + place + QLatin1String("|extra|") + m_place[place].placeCode + QLatin1Char(';')
-                         + m_place[place].displayName);
+        placeList.append(QStringLiteral("|place|%1|extra|%2;%3").arg(place.name, place.placeCode, place.displayName));
     }
 
     qCDebug(IONENGINE_WETTERCOM) << "Returning place list:" << placeList;
 
     if (m_locations.count() > 1) {
-        setData(source, QStringLiteral("validate"), QVariant(QStringLiteral("wettercom|valid|multiple") + placeList));
+        setData(source, QStringLiteral("validate"), QVariant(QString(u"wettercom|valid|multiple" + placeList)));
     } else {
         placeList[7] = placeList[7].toUpper();
-        setData(source, QStringLiteral("validate"), QVariant(QStringLiteral("wettercom|valid|single") + placeList));
+        setData(source, QStringLiteral("validate"), QVariant(QString(u"wettercom|valid|single" + placeList)));
     }
 
     m_locations.clear();
@@ -450,6 +451,7 @@ void WetterComIon::fetchForecast(const QString &source)
     const QString encodedKey = QString::fromLatin1(md5.result().toHex());
 
     const QUrl url(QStringLiteral(FORECAST_URL).arg(m_place[source].placeCode, encodedKey));
+    qCDebug(IONENGINE_WETTERCOM) << "Fetch Weather URL for" << source << url;
 
     KIO::TransferJob *getJob = KIO::get(url, KIO::Reload, KIO::HideProgressInfo);
     getJob->addMetaData(QStringLiteral("cookies"), QStringLiteral("none"));
@@ -488,7 +490,8 @@ void WetterComIon::forecast_slotJobFinished(KJob *job)
 
     if (m_sourcesToReset.contains(source)) {
         m_sourcesToReset.removeAll(source);
-        const QString weatherSource = QStringLiteral("wettercom|weather|%1|%2;%3").arg(source, m_place[source].placeCode, m_place[source].displayName);
+        const PlaceInfo &place = m_place[source];
+        const QString weatherSource = QStringLiteral("wettercom|weather|%1|%2;%3").arg(place.name, place.placeCode, place.displayName);
 
         // so the weather engine updates it's data
         forceImmediateUpdateOfAllVisualizations();
@@ -514,13 +517,11 @@ void WetterComIon::parseWeatherForecast(const QString &source, QXmlStreamReader
     uint summaryUtcTime = 0, utcTime = 0, localTime = 0;
     QString date, time;
 
-    weatherData.place = source;
+    weatherData.place = m_place[source].name;
 
     while (!xml.atEnd()) {
         xml.readNext();
 
-        qCDebug(IONENGINE_WETTERCOM) << "parsing xml elem: " << xml.name();
-
         const auto elementName = xml.name();
 
         if (xml.isEndElement()) {
@@ -545,9 +546,6 @@ void WetterComIon::parseWeatherForecast(const QString &source, QXmlStreamReader
                 summaryUtcTime = 0;
             } else if (elementName == QLatin1String("time")) {
                 // we have parsed one forecast
-
-                qCDebug(IONENGINE_WETTERCOM) << "Parsed a forecast interval:" << date << time;
-
                 // yep, that field is written to more often than needed...
                 weatherData.timeDifference = localTime - utcTime;
 
@@ -560,8 +558,6 @@ void WetterComIon::parseWeatherForecast(const QString &source, QXmlStreamReader
                 QTime localWeatherTime = QDateTime::fromSecsSinceEpoch(utcTime, Qt::LocalTime).time();
                 localWeatherTime = localWeatherTime.addSecs(weatherData.timeDifference);
 
-                qCDebug(IONENGINE_WETTERCOM) << "localWeatherTime =" << localWeatherTime;
-
                 // TODO use local sunset/sunrise time
 
                 if (localWeatherTime.hour() < 20 && localWeatherTime.hour() > 6) {
@@ -592,10 +588,8 @@ void WetterComIon::parseWeatherForecast(const QString &source, QXmlStreamReader
                 time = xml.attributes().value(QStringLiteral("value")).toString();
             } else if (elementName == QLatin1String("tx")) {
                 tempMax = qRound(xml.readElementText().toDouble());
-                qCDebug(IONENGINE_WETTERCOM) << "parsed t_max:" << tempMax;
             } else if (elementName == QLatin1String("tn")) {
                 tempMin = qRound(xml.readElementText().toDouble());
-                qCDebug(IONENGINE_WETTERCOM) << "parsed t_min:" << tempMin;
             } else if (elementName == QLatin1Char('w')) {
                 int tmp = xml.readElementText().toInt();
 
@@ -604,10 +598,8 @@ void WetterComIon::parseWeatherForecast(const QString &source, QXmlStreamReader
                 else
                     summaryWeather = tmp;
 
-                qCDebug(IONENGINE_WETTERCOM) << "parsed weather condition:" << tmp;
             } else if (elementName == QLatin1String("name")) {
                 weatherData.stationName = xml.readElementText();
-                qCDebug(IONENGINE_WETTERCOM) << "parsed station name:" << weatherData.stationName;
             } else if (elementName == QLatin1String("pc")) {
                 int tmp = xml.readElementText().toInt();
 
@@ -616,16 +608,12 @@ void WetterComIon::parseWeatherForecast(const QString &source, QXmlStreamReader
                 else
                     summaryProbability = tmp;
 
-                qCDebug(IONENGINE_WETTERCOM) << "parsed probability:" << probability;
             } else if (elementName == QLatin1String("text")) {
                 weatherData.credits = xml.readElementText();
-                qCDebug(IONENGINE_WETTERCOM) << "parsed credits:" << weatherData.credits;
             } else if (elementName == QLatin1String("link")) {
                 weatherData.creditsUrl = xml.readElementText();
-                qCDebug(IONENGINE_WETTERCOM) << "parsed credits url:" << weatherData.creditsUrl;
             } else if (elementName == QLatin1Char('d')) {
                 localTime = xml.readElementText().toInt();
-                qCDebug(IONENGINE_WETTERCOM) << "parsed local time:" << localTime;
             } else if (elementName == QLatin1String("du")) {
                 int tmp = xml.readElementText().toInt();
 
@@ -633,8 +621,6 @@ void WetterComIon::parseWeatherForecast(const QString &source, QXmlStreamReader
                     utcTime = tmp;
                 else
                     summaryUtcTime = tmp;
-
-                qCDebug(IONENGINE_WETTERCOM) << "parsed UTC time:" << tmp;
             }
         }
     }
@@ -651,7 +637,7 @@ void WetterComIon::updateWeather(const QString &source, bool parseError)
 
     const PlaceInfo &placeInfo = m_place[source];
 
-    QString weatherSource = QStringLiteral("wettercom|weather|%1|%2;%3").arg(source, placeInfo.placeCode, placeInfo.displayName);
+    QString weatherSource = QStringLiteral("wettercom|weather|%1|%2;%3").arg(placeInfo.name, placeInfo.placeCode, placeInfo.displayName);
 
     const WeatherData &weatherData = m_weatherData[source];
 
@@ -659,7 +645,7 @@ void WetterComIon::updateWeather(const QString &source, bool parseError)
     data.insert(QStringLiteral("Place"), placeInfo.displayName);
 
     if (!parseError && !weatherData.forecasts.isEmpty()) {
-        data.insert(QStringLiteral("Station"), placeInfo.displayName);
+        data.insert(QStringLiteral("Station"), placeInfo.name);
         // data.insert("Condition Icon", "N/A");
         // data.insert("Temperature", "N/A");
         data.insert(QStringLiteral("Temperature Unit"), KUnitConversion::Celsius);
@@ -708,9 +694,10 @@ void WetterComIon::updateWeather(const QString &source, bool parseError)
 
         qCDebug(IONENGINE_WETTERCOM) << "updated weather data:" << weatherSource << data;
     } else {
-        qCDebug(IONENGINE_WETTERCOM) << "Something went wrong when parsing weather data for source:" << source;
+        qCDebug(IONENGINE_WETTERCOM) << "Something went wrong when parsing weather data for source:" << source << placeInfo.displayName;
     }
 
+    Q_EMIT cleanUpData(source);
     setData(weatherSource, data);
 }
 
