@@ -20,6 +20,8 @@
 #include "desktopnotifier_interface.h"
 #include "kded_interface.h"
 
+using namespace Qt::StringLiterals;
+
 // Pseudo plugin class to embed meta data
 class KIOPluginForMetaData : public QObject
 {
@@ -32,7 +34,7 @@ int Q_DECL_EXPORT kdemain(int argc, char **argv)
 {
     // necessary to use other kio workers
     QCoreApplication app(argc, argv);
-    app.setApplicationName("kio_desktop");
+    app.setApplicationName(u"kio_desktop"_s);
 
     // start the worker
     DesktopProtocol worker(argv[1], argv[2], argv[3]);
@@ -47,7 +49,7 @@ DesktopProtocol::DesktopProtocol(const QByteArray &protocol, const QByteArray &p
     checkLocalInstall();
 
     org::kde::kded6 kded(QStringLiteral("org.kde.kded6"), QStringLiteral("/kded"), QDBusConnection::sessionBus());
-    auto pending = kded.loadModule("desktopnotifier");
+    auto pending = kded.loadModule(u"desktopnotifier"_s);
     pending.waitForFinished();
 }
 
@@ -67,14 +69,15 @@ void DesktopProtocol::checkLocalInstall()
 
     // Create the desktop folder if it doesn't exist
     if (!desktopDir.exists()) {
-        ::mkdir(QFile::encodeName(desktopPath), S_IRWXU);
+        ::mkdir(QFile::encodeName(desktopPath).constData(), S_IRWXU);
         desktopIsEmpty = true;
     } else
         desktopIsEmpty = desktopDir.entryList(QDir::AllEntries | QDir::Hidden | QDir::NoDotAndDotDot).isEmpty();
 
     if (desktopIsEmpty) {
         // Copy the .directory file
-        QFile::copy(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kio_desktop/directory.desktop")), desktopPath + "/.directory");
+        QFile::copy(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kio_desktop/directory.desktop")),
+                    desktopPath + "/.directory"_L1);
 
         // Copy the desktop links
         QSet<QString> links;
@@ -87,7 +90,7 @@ void DesktopProtocol::checkLocalInstall()
             }
         }
 
-        foreach (const QString &link, links) {
+        for (const QString &link : std::as_const(links)) {
             const auto fullPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kio_desktop/DesktopLinks/%1").arg(link));
             KDesktopFile file(fullPath);
             if (!file.desktopGroup().readEntry("Hidden", false))
