@@ -197,9 +197,10 @@ PanelConfigView::PanelConfigView(Plasma::Containment *containment, PanelView *pa
     , m_panelView(panelView)
     , m_sharedQmlEngine(std::make_unique<PlasmaQuick::SharedQmlEngine>(this))
 {
-    setProperty("restrictedPopupGeometry", QVariant(containment->corona()->availableScreenRect(m_containment->screen())));
-    connect(m_containment, &Plasma::Containment::screenChanged, this, [this](int screen) {
-        setProperty("restrictedPopupGeometry", QVariant(m_containment->corona()->availableScreenRect(screen)));
+    ShellCorona *c = qobject_cast<ShellCorona *>(m_containment->corona());
+    setProperty("restrictedPopupGeometry", QVariant(c->availableScreenRect(m_containment->screen())));
+    connect(m_containment, &Plasma::Containment::screenChanged, this, [this, c](int screen) {
+        setProperty("restrictedPopupGeometry", QVariant(c->availableScreenRect(screen)));
     });
 
     connect(panelView, &QObject::destroyed, this, &QObject::deleteLater);
