@@ -7,15 +7,15 @@
 
 #include "userfeedback.h"
 
-#include <KUserFeedbackQt6/ApplicationVersionSource>
-#include <KUserFeedbackQt6/CompilerInfoSource>
-#include <KUserFeedbackQt6/OpenGLInfoSource>
-#include <KUserFeedbackQt6/PlatformInfoSource>
-#include <KUserFeedbackQt6/Provider>
-#include <KUserFeedbackQt6/QPAInfoSource>
-#include <KUserFeedbackQt6/QtVersionSource>
-#include <KUserFeedbackQt6/ScreenInfoSource>
-#include <KUserFeedbackQt6/UsageTimeSource>
+#include <KUserFeedback/ApplicationVersionSource>
+#include <KUserFeedback/CompilerInfoSource>
+#include <KUserFeedback/OpenGLInfoSource>
+#include <KUserFeedback/PlatformInfoSource>
+#include <KUserFeedback/Provider>
+#include <KUserFeedback/QPAInfoSource>
+#include <KUserFeedback/QtVersionSource>
+#include <KUserFeedback/ScreenInfoSource>
+#include <KUserFeedback/UsageTimeSource>
 
 #include <KLocalizedString>
 
@@ -69,8 +69,8 @@ UserFeedback::UserFeedback(ShellCorona *corona, QObject *parent)
     m_provider->addDataSource(new PanelCountSource(corona));
 
     auto plasmaConfig = KSharedConfig::openConfig(QStringLiteral("PlasmaUserFeedback"));
-    m_provider->setTelemetryMode(
-        KUserFeedback::Provider::TelemetryMode(plasmaConfig->group("Global").readEntry("FeedbackLevel", int(KUserFeedback::Provider::NoTelemetry))));
+    m_provider->setTelemetryMode(KUserFeedback::Provider::TelemetryMode(
+        plasmaConfig->group(QStringLiteral("Global")).readEntry("FeedbackLevel", int(KUserFeedback::Provider::NoTelemetry))));
 }
 
 QString UserFeedback::describeDataSources() const
